]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - mysql.c
Rename random_dbtool.c to random_selector.c
[paraslash.git] / mysql.c
diff --git a/mysql.c b/mysql.c
index 9760f0865ab9c7682fdf3afda8bc6e72d0a9b29b..9292ab29a0cddc07e03e8a86c85061c1f9e85116 100644 (file)
--- a/mysql.c
+++ b/mysql.c
@@ -16,7 +16,7 @@
  *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */
 
/** \file mysql.c para_server's mysql-based database tool */
 
 /** \cond some internal constants */
 #define MEDIUM_BLOB_SIZE 16777220 /*  (2**24 + 4) */
@@ -2514,9 +2514,9 @@ static void shutdown_connection(void)
  * Check the command line options and initialize all function pointers of \a db.
  * Connect to the mysql server and initialize the dbinfo string.
  *
- * \sa struct dbtool, misc_meta_data::dbinfo, random_dbtool.c
+ * \sa struct audio_file_selector, misc_meta_data::dbinfo, random_selector.c
  */
-int mysql_dbtool_init(struct dbtool *db)
+int mysql_selector_init(struct audio_file_selector *db)
 {
        int ret;
@@ -16,7 +16,7 @@
  */
 
-/** \file mysql.c para_server's mysql-based database tool */
+/** \file mysql.c para_server's mysql-based audio file selector */
 
 /** \cond some internal constants */